==> eccodes-2.39.0.x86_64_linux.bottle.tar.gz: eccodes/2.39.0/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ECCODES_ecbuild_config_h
#define ECCODES_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.9.0"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.9.0"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/tmp/eccodes-20241121-6430-q1kx1p/eccodes-2.39.0-Source/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Linux-6.5.0-1025-azure"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "linux.64"
#define ECCODES_OS_VERSION       "6.5.0-1025-azure"
#define ECCODES_SYS_PROCESSOR    "x86_64"

#define ECCODES_BUILD_TIMESTAMP  "20241121153805"
#define ECCODES_BUILD_TYPE       "Release"

#define ECCODES_C_COMPILER_ID      "GNU"
#define ECCODES_C_COMPILER_VERSION "11.4.0"

#define ECCODES_CXX_COMPILER_ID      "GNU"
#define ECCODES_CXX_COMPILER_VERSION "11.4.0"

#define ECCODES_C_COMPILER       "gcc-11"
#define ECCODES_C_FLAGS          " -pipe -O3 -DNDEBUG"

#define ECCODES_CXX_COMPILER     "g++-11"
#define ECCODES_CXX_FLAGS        " -pipe -O3 -DNDEBUG"

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "@@HOMEBREW_CELLAR@@/eccodes/2.39.0"
#define ECCODES_INSTALL_BIN_DIR   "@@HOMEBREW_CELLAR@@/eccodes/2.39.0/bin"
#define ECCODES_INSTALL_LIB_DIR   "@@HOMEBREW_CELLAR@@/eccodes/2.39.0/lib"
#define ECCODES_INSTALL_DATA_DIR  "@@HOMEBREW_CELLAR@@/eccodes/2.39.0/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "/tmp/eccodes-20241121-6430-q1kx1p/eccodes-2.39.0-Source"
#define ECCODES_DEVELOPER_BIN_DIR "/tmp/eccodes-20241121-6430-q1kx1p/eccodes-2.39.0-Source/build"

/* Fortran support */

#if 1

#define ECCODES_Fortran_COMPILER_ID      "GNU"
#define ECCODES_Fortran_COMPILER_VERSION "14.2.0"

#define ECCODES_Fortran_COMPILER "@@HOMEBREW_PREFIX@@/bin/gfortran"
#define ECCODES_Fortran_FLAGS    " -O3 -DNDEBUG -funroll-all-loops -finline-functions"

#endif

#endif /* ECCODES_ecbuild_config_h */

==> eccodes-2.42.0.x86_64_linux.bottle.tar.gz: eccodes/2.42.0/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ECCODES_ecbuild_config_h
#define ECCODES_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.11.0"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.11.0"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/var/tmp/eccodes-20250630-6833-pe4vcc/eccodes-2.42.0-Source/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Linux-6.11.0-1015-azure"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "linux.64"
#define ECCODES_OS_VERSION       "6.11.0-1015-azure"
#define ECCODES_SYS_PROCESSOR    "x86_64"

#define ECCODES_BUILD_TIMESTAMP  "20250630110535"
#define ECCODES_BUILD_TYPE       "Release"

#define ECCODES_C_COMPILER_ID      "GNU"
#define ECCODES_C_COMPILER_VERSION "11.4.0"

#define ECCODES_CXX_COMPILER_ID      "GNU"
#define ECCODES_CXX_COMPILER_VERSION "11.4.0"

#define ECCODES_C_COMPILER       "gcc-11"
#define ECCODES_C_FLAGS          " -pipe -O3 -DNDEBUG"

#define ECCODES_CXX_COMPILER     "g++-11"
#define ECCODES_CXX_FLAGS        " -pipe -O3 -DNDEBUG"

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "@@HOMEBREW_CELLAR@@/eccodes/2.42.0"
#define ECCODES_INSTALL_BIN_DIR   "@@HOMEBREW_CELLAR@@/eccodes/2.42.0/bin"
#define ECCODES_INSTALL_LIB_DIR   "@@HOMEBREW_CELLAR@@/eccodes/2.42.0/lib"
#define ECCODES_INSTALL_DATA_DIR  "@@HOMEBREW_CELLAR@@/eccodes/2.42.0/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "/var/tmp/eccodes-20250630-6833-pe4vcc/eccodes-2.42.0-Source"
#define ECCODES_DEVELOPER_BIN_DIR "/var/tmp/eccodes-20250630-6833-pe4vcc/eccodes-2.42.0-Source/build"

/* Fortran support */

#if 1

#define ECCODES_Fortran_COMPILER_ID      "GNU"
#define ECCODES_Fortran_COMPILER_VERSION "15.1.0"

#define ECCODES_Fortran_COMPILER "@@HOMEBREW_PREFIX@@/bin/gfortran"
#define ECCODES_Fortran_FLAGS    " -O3 -DNDEBUG -funroll-all-loops -finline-functions"

#endif

#endif /* ECCODES_ecbuild_config_h */
